==> 0.0.1.tar.gz: lib/webviewConscent.dart <==
import 'dart:convert';
import 'package:flutter_conscent_plugin/ConscentInitializer.dart';
import 'package:flutter_conscent_plugin/defaultSubscribtion.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'Model/APIMode.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppss(),
    ),
  );
}

class WebViewAppss extends StatefulWidget {
  const WebViewAppss({super.key});

  @override
  State<WebViewAppss> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewAppss> {
  String? loginId;
  // Add from here ...
  bool showContent = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();

  // @override
  // void initState() {
  //   if (Platform.isAndroid) {
  //     //  WebView.platform = SurfaceAndroidWebView();
  //   }
  //   super.initState();
  // }
  // ... to here.

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('dev sessionnnnnnnnnnnnn id');
      print(prefs.getString('sessionId'));
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      print("dataMain");
      print(dataMain);
      print("dataMain");
      CircularProgressIndicator();
      return sessionId;
      // Navigator.pop(context,{
      //   "sessionId":dataMain['sessionId']
      // });
    }
    return '';
  }

  dynamic dataMains;
  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": clientId,
      "clientContentId": clientContentId,
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;
      Navigator.pop(context, {"response": responseString});
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    var flutterWebViewPlugin;
    print(loginId);
    print(sessionId);
    print('kunallllllll');

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  //  'https://conscent.netlify.app/overlay?clientId=5f92a62013332e0f667794dc&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                  'https://csc-subs-stage.netlify.app/design?clientContentId=${ConscentInitializer.mContentId}&clientId=${ConscentInitializer.mClientId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                //  getSessionID(loginId.toString());
                //   submitDatas(clientId.text, clientContentId.text,sessionId);
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');
                //    javascriptChannels: <JavascriptChannel>{_javascriptChannel()};
                if (request.url.startsWith('https://xyz.zyz')) {
                  //    javascriptChannels: <JavascriptChannel>{_javascriptChannel()};
                  print('APIU CALL FIRST');
                  //    getSessionID(loginId.toString());
                  //   submitDatas(clientId.text, clientContentId.text,sessionId);
                  getSessionID(loginId!);
                  //  7500757759

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    'https://conscentsss.com/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}

==> 0.1.7.tar.gz: lib/webviewConscent.dart <==
// ignore_for_file: file_names
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import '../Model/APIMode.dart';
import 'ConscentInitializer.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppss(),
    ),
  );
}

class WebViewAppss extends StatefulWidget {
  const WebViewAppss({super.key});

  @override
  State<WebViewAppss> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewAppss> {
  String? loginId;
  bool showContent = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

//getLoginChallengeId
  dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    getSessionID(loginId.toString());
    setState(() {});
  }

//login-challenge
  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      return sessionId;
    }
    return '';
  }

//content access
  dynamic dataMains;
  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": clientId,
      "clientContentId": clientContentId,
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;
      // ignore: use_build_context_synchronously
      Navigator.pop(context, {"response": responseString});
    }
  }

  JavascriptChannel _javascriptChannel() {
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          if (message.message == 'loginSuccess') {
            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  '${APIMode.SERVICE_BASE_URL}/design?clientContentId=${ConscentInitializer.mContentId}&clientId=${ConscentInitializer.mClientId}&loginChallenge=$loginId',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                <JavascriptChannel>{_javascriptChannel()};
              },
              onWebViewCreated: (controller) {},
              navigationDelegate: (NavigationRequest request) {
                if (request.url.startsWith('https://xyz.zyz')) {
                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  Navigator.pop(context);
                }

                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {},
              onPageFinished: (String url) {},
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : const Center(child: CircularProgressIndicator()),
    );
  }
}
